@@ -4,7 +4,7 @@ package Date::Formatter;
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 ## overload operators
 use overload (
@@ -459,7 +459,7 @@ __END__
 
 =head1 NAME
 
-Date-Formatter - A simple Date and Time formatting object 
+Date::Formatter - A simple Date and Time formatting object 
 
 =head1 SYNOPSIS
 
@@ -501,7 +501,9 @@ This module provides a fast and very flexible mini-language to be used in format
 
 =over 4
 
-=item B<new>, B<now> 
+=item B<new>
+
+=item B<now> 
 
 C<new> or C<now> will create a B<Date::Formatter> object with the current time.
 
@@ -520,10 +522,6 @@ Accepts the following named arguments:
  minutes
  seconds
 
-B<NOTE:> 
-
-This can also be used to set a time sometime past the epoch, but that is not terribly useful. Except maybe to pass in nothing and get the date of the epoch on your current system.
-
 =item B<refresh>
 
 Occasionally you will want to refresh the time to be the current time. This would allow a B<Date::Formatter> object to be used over a long period of time.
@@ -532,14 +530,10 @@ Occasionally you will want to refresh the time to be the current time. This woul
 
 =head2 Formatted Output Methods
 
+The formatted output methods are means of customizing the string output of the B<Date::Formatter> object. The C<createDateFormatter> is at the heart of this group, it implements a mini-language for formatting dates. The internal parser in C<createDateFormatter> has been optimized to make this a very usable operation, as it will be one of the most common uses of this object.
+
 =over 4
 
-The formatted output methods are means of customizing the string output of the B<Date::Formatter> object. The C<createDateFormatter> is at the heart of this group, it implements a mini-language for formatting dates. 
-
-B<NOTE:> 
-
-That the internal parser in C<createDateFormatter> has been optimized to make this a very usable operation, as it will be one of the most common uses of this object.
-
 =item B<createDateFormatter ($format_string)>
 
 All date tokens must be enclosed in parantheses (or some other seperator for which you must provide the regular expression that C<split> will use to tokenize the string). The formatter will use the current settings for 12 or 24 hour clock as well as the abbreviated day and month names. Here is a description of the available tokens and what they output:
@@ -596,10 +590,12 @@ here is a format that will exactly mimic the default date format
 
 =item B<getDateFormatter>
 
-returns the formatter subroutine, so you can share between multiple B<Date::Formatter> objects if you like.
+Returns the formatter subroutine, so you can share between multiple B<Date::Formatter> objects if you like.
 
 =item B<setDateFormatter ($func)>
 
+Sets the formatter routine, this is how one would share that formatter routine mentioned above.
+
 =back
 
 =head2 Configuration methods
@@ -688,7 +684,7 @@ These methods overload the + and - operators respectively.
 
 =item B<toString>
 
-A C<toString> method is implemented, and used to overload the '""' stringification operator.
+This method returns the formatted string as specified by the C<createDateFormatter> method. This is used to overload the '""' stringification operator.
 
 =item B<compare>
 
@@ -739,6 +735,8 @@ Possibly incorporate a timer class with this as well, with C<start> and C<stop>
 
 Using date formatters on time intervals does not always make sense, as it will just give you a representation of the interval past after the epoch. Possibly consider an alternate format for intervals. This would likely require some reworking of the way intervals are handled so it is only an idea for now.
 
+This documentation needs some work.
+
 =head1 BUGS
 
 None that I am aware of. The code is pretty thoroughly tested (see L<CODE COVERAGE> below) and is based on an (non-publicly released) module which I had used in production systems for over 2 years without incident. Of course, if you find a bug, let me know, and I will be sure to fix it. 
